You are viewing a plain text version of this content. The canonical link for it is here.
Posted to fop-commits@xmlgraphics.apache.org by ma...@apache.org on 2008/06/24 13:59:34 UTC

svn commit: r671145 - /xmlgraphics/fop/trunk/src/java/org/apache/fop/fo/pagination/bookmarks/BookmarkTitle.java

Author: maxberger
Date: Tue Jun 24 04:59:33 2008
New Revision: 671145

URL: http://svn.apache.org/viewvc?rev=671145&view=rev
Log:
Another character handling problem, replaced end-start by length

Modified:
    xmlgraphics/fop/trunk/src/java/org/apache/fop/fo/pagination/bookmarks/BookmarkTitle.java

Modified: xmlgraphics/fop/trunk/src/java/org/apache/fop/fo/pagination/bookmarks/BookmarkTitle.java
URL: http://svn.apache.org/viewvc/xmlgraphics/fop/trunk/src/java/org/apache/fop/fo/pagination/bookmarks/BookmarkTitle.java?rev=671145&r1=671144&r2=671145&view=diff
==============================================================================
--- xmlgraphics/fop/trunk/src/java/org/apache/fop/fo/pagination/bookmarks/BookmarkTitle.java (original)
+++ xmlgraphics/fop/trunk/src/java/org/apache/fop/fo/pagination/bookmarks/BookmarkTitle.java Tue Jun 24 04:59:33 2008
@@ -51,13 +51,13 @@
      *
      * @param data the character data
      * @param start the start position in the data array
      * @param end the end position in the character array
      * @param locator location in fo source file.
      */
-    protected void addCharacters(char[] data, int start, int end,
+    protected void addCharacters(char[] data, int start, int length,
                                  PropertyList pList,
                                  Locator locator) {
-        title += new String(data, start, end - start);
+        title += new String(data, start, length);
     }
 
     /**



---------------------------------------------------------------------
@@ -51,13 +51,13 @@
      * @param data the character data
      * @param start the start position in the data array
-     * @param end the end position in the character array
+     * @param length the length of the character array
      * @param locator location in fo source file.
      */
To unsubscribe, e-mail: fop-commits-unsubscribe@xmlgraphics.apache.org
For additional commands, e-mail: fop-commits-help@xmlgraphics.apache.org